@@ -6,8 +6,8 @@
 ;; Created: January 2018
 ;; Keywords: extensions mail
 ;; Homepage: https://github.com/jeremy-compostella/org-msg
-;; Package-Version: 20260113.1253
-;; Package-Revision: b7f17693739c
+;; Package-Version: 20260129.1431
+;; Package-Revision: 0c93f4d6250c
 ;; Package-Requires: ((emacs "24.4") (htmlize "1.54"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -756,7 +756,9 @@ absolute paths."
 	(with-current-buffer (org-ascii-export-as-ascii)
 	  (while (re-search-forward "<file:\\\([a-z0-9AZ_\./-]+\\\)>" nil t)
 	    (setf files (push (match-string-no-properties 1) files)))
-	  (cl-values (buffer-string) files))))))
+	  (let ((content (cl-values (buffer-string) files)))
+	    (kill-buffer)
+	    content))))))
 
 (defun org-msg-export-as-html (str)
   "Transform the Org STR into html."
